/************************************************************************************
 *  File:     BSP.c
 *  Purpose:  Board support package for ATSAMA5D33_EK.
 *  Date:     02 April 2014
 ************************************************************************************/

#include "BSP.h"

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/

/****** SFRs and identifiers used for LED demo **********************/

#define LED_RED_PIN                   (24u) // Led DL1 on Ronetix CPU module
#define LED_BLUE                      (25u) // Led DL2 on Ronetix CPU module

#define PMC_BASE_ADDR                 (0xFFFFFC00u)
#define PMC_PCER0                     (*(volatile unsigned int*)(PMC_BASE_ADDR + 0x010u)) // PMC Peripheral Clock Enable Register 0
#define PMC_WPMR                      (*(volatile unsigned int*)(PMC_BASE_ADDR + 0x0E4u)) // PMC Write Protect Mode Register

#define PIOE_BASE_ADDR                (0xFFFFFA00u)
#define PIOE_PER                      (*(volatile unsigned int*) (PIOE_BASE_ADDR + 0x00)) // PIO Enable Register
#define PIOE_OER0                     (*(volatile unsigned int*) (PIOE_BASE_ADDR + 0x10)) // Output Enable Register
#define PIOE_SODR                     (*(volatile unsigned int*) (PIOE_BASE_ADDR + 0x30)) // Set Output Data Register
#define PIOE_CODR                     (*(volatile unsigned int*) (PIOE_BASE_ADDR + 0x34)) // Clear Output Data Register
#define PIOE_ODSR                     (*(volatile unsigned int*) (PIOE_BASE_ADDR + 0x38)) // Output Data Status Register
#define PIOE_ID                       (10u)

/****** Addresses of sfrs and peripheral identifiers ****************/

#define WP_ENABLE                     (0x504D4301u)
#define WP_DISABLE                    (0x504D4300u)

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       BSP_Init()
*/
void BSP_Init(void) {
  //
  // Enable clock for PIOE
  //
  PMC_WPMR  = WP_DISABLE;       // Disable write protect
  PMC_PCER0 = (1u << PIOE_ID);  // Enable clock for PIOE
  //
  // Enable led port pins and set to output
  //
  PIOE_PER  = (1u << LED_RED_PIN) | (1u << LED_BLUE);
  PIOE_OER0 = (1u << LED_RED_PIN) | (1u << LED_BLUE);
}

/*********************************************************************
*
*       BSP_SetLED()
*/
void BSP_SetLED(int Index) {
  if (Index == 0) {
    PIOE_CODR = (1u << LED_BLUE);
  } else if (Index == 1) {
    PIOE_CODR = (1u << LED_RED_PIN);
  }
}

/*********************************************************************
*
*       BSP_ClrLED()
*/
void BSP_ClrLED(int Index) {
  if (Index == 0) {
    PIOE_SODR = (1u << LED_BLUE);
  } else if (Index == 1) {
    PIOE_SODR = (1u << LED_RED_PIN);
  }
}

/*********************************************************************
*
*       BSP_ToggleLED()
*/
void BSP_ToggleLED(int Index) {
  if (Index == 0) {
    if ((PIOE_ODSR & (1u << LED_BLUE)) == (1u << LED_BLUE)) {
      PIOE_CODR = (1u << LED_BLUE);
    } else {
      PIOE_SODR = (1u << LED_BLUE);
    }
  } else if (Index == 1) {
    if ((PIOE_ODSR & (1u << LED_RED_PIN)) == (1u << LED_RED_PIN)) {
      PIOE_CODR = (1u << LED_RED_PIN);
    } else {
      PIOE_SODR = (1u << LED_RED_PIN);
    }
  }
}

/****** End Of File *************************************************/
